==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/IngressStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class IngressStatusFluentImpl<A extends io.fabric8.openshift.api.model.IngressStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.IngressStatusFluent<A>{
  public IngressStatusFluentImpl() {
  }
  public IngressStatusFluentImpl(io.fabric8.openshift.api.model.IngressStatus instance) {
    this.withComponentRoutes(instance.getComponentRoutes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder> componentRoutes =  new java.util.ArrayList<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToComponentRoutes(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteStatus item) {
    if (this.componentRoutes == null) {this.componentRoutes = new java.util.ArrayList<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder>();}
    io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(item);_visitables.get("componentRoutes").add(index >= 0 ? index : _visitables.get("componentRoutes").size(), builder);this.componentRoutes.add(index >= 0 ? index : componentRoutes.size(), builder); return (A)this;
  }
  public A setToComponentRoutes(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteStatus item) {
    if (this.componentRoutes == null) {this.componentRoutes = new java.util.ArrayList<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder>();}
    io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(item);
    if (index < 0 || index >= _visitables.get("componentRoutes").size()) { _visitables.get("componentRoutes").add(builder); } else { _visitables.get("componentRoutes").set(index, builder);}
    if (index < 0 || index >= componentRoutes.size()) { componentRoutes.add(builder); } else { componentRoutes.set(index, builder);}
     return (A)this;
  }
  public A addToComponentRoutes(io.fabric8.openshift.api.model.ComponentRouteStatus... items) {
    if (this.componentRoutes == null) {this.componentRoutes = new java.util.ArrayList<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder>();}
    for (io.fabric8.openshift.api.model.ComponentRouteStatus item : items) {io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(item);_visitables.get("componentRoutes").add(builder);this.componentRoutes.add(builder);} return (A)this;
  }
  public A addAllToComponentRoutes(java.util.Collection<io.fabric8.openshift.api.model.ComponentRouteStatus> items) {
    if (this.componentRoutes == null) {this.componentRoutes = new java.util.ArrayList<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder>();}
    for (io.fabric8.openshift.api.model.ComponentRouteStatus item : items) {io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(item);_visitables.get("componentRoutes").add(builder);this.componentRoutes.add(builder);} return (A)this;
  }
  public A removeFromComponentRoutes(io.fabric8.openshift.api.model.ComponentRouteStatus... items) {
    for (io.fabric8.openshift.api.model.ComponentRouteStatus item : items) {io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(item);_visitables.get("componentRoutes").remove(builder);if (this.componentRoutes != null) {this.componentRoutes.remove(builder);}} return (A)this;
  }
  public A removeAllFromComponentRoutes(java.util.Collection<io.fabric8.openshift.api.model.ComponentRouteStatus> items) {
    for (io.fabric8.openshift.api.model.ComponentRouteStatus item : items) {io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(item);_visitables.get("componentRoutes").remove(builder);if (this.componentRoutes != null) {this.componentRoutes.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromComponentRoutes(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder> predicate) {
    if (componentRoutes == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder> each = componentRoutes.iterator();
    final List visitables = _visitables.get("componentRoutes");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildComponentRoutes instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.ComponentRouteStatus> getComponentRoutes() {
    return build(componentRoutes);
  }
  public java.util.List<io.fabric8.openshift.api.model.ComponentRouteStatus> buildComponentRoutes() {
    return build(componentRoutes);
  }
  public io.fabric8.openshift.api.model.ComponentRouteStatus buildComponentRoute(java.lang.Integer index) {
    return this.componentRoutes.get(index).build();
  }
  public io.fabric8.openshift.api.model.ComponentRouteStatus buildFirstComponentRoute() {
    return this.componentRoutes.get(0).build();
  }
  public io.fabric8.openshift.api.model.ComponentRouteStatus buildLastComponentRoute() {
    return this.componentRoutes.get(componentRoutes.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.ComponentRouteStatus buildMatchingComponentRoute(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder> predicate) {
    for (io.fabric8.openshift.api.model.ComponentRouteStatusBuilder item: componentRoutes) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingComponentRoute(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder> predicate) {
    for (io.fabric8.openshift.api.model.ComponentRouteStatusBuilder item: componentRoutes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withComponentRoutes(java.util.List<io.fabric8.openshift.api.model.ComponentRouteStatus> componentRoutes) {
    if (this.componentRoutes != null) { _visitables.get("componentRoutes").removeAll(this.componentRoutes);}
    if (componentRoutes != null) {this.componentRoutes = new java.util.ArrayList<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder>(); for (io.fabric8.openshift.api.model.ComponentRouteStatus item : componentRoutes){this.addToComponentRoutes(item);}} else { this.componentRoutes = null;} return (A) this;
  }
  public A withComponentRoutes(io.fabric8.openshift.api.model.ComponentRouteStatus... componentRoutes) {
    if (this.componentRoutes != null) {this.componentRoutes.clear();}
    if (componentRoutes != null) {for (io.fabric8.openshift.api.model.ComponentRouteStatus item :componentRoutes){ this.addToComponentRoutes(item);}} return (A) this;
  }
  public java.lang.Boolean hasComponentRoutes() {
    return componentRoutes != null && !componentRoutes.isEmpty();
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> addNewComponentRoute() {
    return new io.fabric8.openshift.api.model.IngressStatusFluentImpl.ComponentRoutesNestedImpl();
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> addNewComponentRouteLike(io.fabric8.openshift.api.model.ComponentRouteStatus item) {
    return new io.fabric8.openshift.api.model.IngressStatusFluentImpl.ComponentRoutesNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> setNewComponentRouteLike(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteStatus item) {
    return new io.fabric8.openshift.api.model.IngressStatusFluentImpl.ComponentRoutesNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> editComponentRoute(java.lang.Integer index) {
    if (componentRoutes.size() <= index) throw new RuntimeException("Can't edit componentRoutes. Index exceeds size.");
    return setNewComponentRouteLike(index, buildComponentRoute(index));
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> editFirstComponentRoute() {
    if (componentRoutes.size() == 0) throw new RuntimeException("Can't edit first componentRoutes. The list is empty.");
    return setNewComponentRouteLike(0, buildComponentRoute(0));
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> editLastComponentRoute() {
    int index = componentRoutes.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last componentRoutes. The list is empty.");
    return setNewComponentRouteLike(index, buildComponentRoute(index));
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> editMatchingComponentRoute(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder> predicate) {
    int index = -1;
    for (int i=0;i<componentRoutes.size();i++) { 
    if (predicate.test(componentRoutes.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching componentRoutes. No match found.");
    return setNewComponentRouteLike(index, buildComponentRoute(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IngressStatusFluentImpl that = (IngressStatusFluentImpl) o;
    if (componentRoutes != null ? !componentRoutes.equals(that.componentRoutes) :that.componentRoutes != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(componentRoutes,  additionalProperties,  super.hashCode());
  }
  public class ComponentRoutesNestedImpl<N> extends io.fabric8.openshift.api.model.ComponentRouteStatusFluentImpl<io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<N>> implements io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ComponentRoutesNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteStatus item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(this, item);
    }
    ComponentRoutesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(this);
    }
    io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) IngressStatusFluentImpl.this.setToComponentRoutes(index,builder.build());
    }
    public N endComponentRoute() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/IngressStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class IngressStatusFluentImpl<A extends io.fabric8.openshift.api.model.IngressStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.IngressStatusFluent<A>{
  public IngressStatusFluentImpl() {
  }
  public IngressStatusFluentImpl(io.fabric8.openshift.api.model.IngressStatus instance) {
    this.withComponentRoutes(instance.getComponentRoutes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder> componentRoutes =  new java.util.ArrayList<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToComponentRoutes(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteStatus item) {
    if (this.componentRoutes == null) {this.componentRoutes = new java.util.ArrayList<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder>();}
    io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(item);_visitables.get("componentRoutes").add(index >= 0 ? index : _visitables.get("componentRoutes").size(), builder);this.componentRoutes.add(index >= 0 ? index : componentRoutes.size(), builder); return (A)this;
  }
  public A setToComponentRoutes(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteStatus item) {
    if (this.componentRoutes == null) {this.componentRoutes = new java.util.ArrayList<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder>();}
    io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(item);
    if (index < 0 || index >= _visitables.get("componentRoutes").size()) { _visitables.get("componentRoutes").add(builder); } else { _visitables.get("componentRoutes").set(index, builder);}
    if (index < 0 || index >= componentRoutes.size()) { componentRoutes.add(builder); } else { componentRoutes.set(index, builder);}
     return (A)this;
  }
  public A addToComponentRoutes(io.fabric8.openshift.api.model.ComponentRouteStatus... items) {
    if (this.componentRoutes == null) {this.componentRoutes = new java.util.ArrayList<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder>();}
    for (io.fabric8.openshift.api.model.ComponentRouteStatus item : items) {io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(item);_visitables.get("componentRoutes").add(builder);this.componentRoutes.add(builder);} return (A)this;
  }
  public A addAllToComponentRoutes(java.util.Collection<io.fabric8.openshift.api.model.ComponentRouteStatus> items) {
    if (this.componentRoutes == null) {this.componentRoutes = new java.util.ArrayList<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder>();}
    for (io.fabric8.openshift.api.model.ComponentRouteStatus item : items) {io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(item);_visitables.get("componentRoutes").add(builder);this.componentRoutes.add(builder);} return (A)this;
  }
  public A removeFromComponentRoutes(io.fabric8.openshift.api.model.ComponentRouteStatus... items) {
    for (io.fabric8.openshift.api.model.ComponentRouteStatus item : items) {io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(item);_visitables.get("componentRoutes").remove(builder);if (this.componentRoutes != null) {this.componentRoutes.remove(builder);}} return (A)this;
  }
  public A removeAllFromComponentRoutes(java.util.Collection<io.fabric8.openshift.api.model.ComponentRouteStatus> items) {
    for (io.fabric8.openshift.api.model.ComponentRouteStatus item : items) {io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(item);_visitables.get("componentRoutes").remove(builder);if (this.componentRoutes != null) {this.componentRoutes.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromComponentRoutes(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder> predicate) {
    if (componentRoutes == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder> each = componentRoutes.iterator();
    final List visitables = _visitables.get("componentRoutes");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildComponentRoutes instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.ComponentRouteStatus> getComponentRoutes() {
    return build(componentRoutes);
  }
  public java.util.List<io.fabric8.openshift.api.model.ComponentRouteStatus> buildComponentRoutes() {
    return build(componentRoutes);
  }
  public io.fabric8.openshift.api.model.ComponentRouteStatus buildComponentRoute(java.lang.Integer index) {
    return this.componentRoutes.get(index).build();
  }
  public io.fabric8.openshift.api.model.ComponentRouteStatus buildFirstComponentRoute() {
    return this.componentRoutes.get(0).build();
  }
  public io.fabric8.openshift.api.model.ComponentRouteStatus buildLastComponentRoute() {
    return this.componentRoutes.get(componentRoutes.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.ComponentRouteStatus buildMatchingComponentRoute(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder> predicate) {
    for (io.fabric8.openshift.api.model.ComponentRouteStatusBuilder item: componentRoutes) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingComponentRoute(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder> predicate) {
    for (io.fabric8.openshift.api.model.ComponentRouteStatusBuilder item: componentRoutes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withComponentRoutes(java.util.List<io.fabric8.openshift.api.model.ComponentRouteStatus> componentRoutes) {
    if (this.componentRoutes != null) { _visitables.get("componentRoutes").removeAll(this.componentRoutes);}
    if (componentRoutes != null) {this.componentRoutes = new java.util.ArrayList(); for (io.fabric8.openshift.api.model.ComponentRouteStatus item : componentRoutes){this.addToComponentRoutes(item);}} else { this.componentRoutes = null;} return (A) this;
  }
  public A withComponentRoutes(io.fabric8.openshift.api.model.ComponentRouteStatus... componentRoutes) {
    if (this.componentRoutes != null) {this.componentRoutes.clear();}
    if (componentRoutes != null) {for (io.fabric8.openshift.api.model.ComponentRouteStatus item :componentRoutes){ this.addToComponentRoutes(item);}} return (A) this;
  }
  public java.lang.Boolean hasComponentRoutes() {
    return componentRoutes != null && !componentRoutes.isEmpty();
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> addNewComponentRoute() {
    return new io.fabric8.openshift.api.model.IngressStatusFluentImpl.ComponentRoutesNestedImpl();
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> addNewComponentRouteLike(io.fabric8.openshift.api.model.ComponentRouteStatus item) {
    return new io.fabric8.openshift.api.model.IngressStatusFluentImpl.ComponentRoutesNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> setNewComponentRouteLike(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteStatus item) {
    return new io.fabric8.openshift.api.model.IngressStatusFluentImpl.ComponentRoutesNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> editComponentRoute(java.lang.Integer index) {
    if (componentRoutes.size() <= index) throw new RuntimeException("Can't edit componentRoutes. Index exceeds size.");
    return setNewComponentRouteLike(index, buildComponentRoute(index));
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> editFirstComponentRoute() {
    if (componentRoutes.size() == 0) throw new RuntimeException("Can't edit first componentRoutes. The list is empty.");
    return setNewComponentRouteLike(0, buildComponentRoute(0));
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> editLastComponentRoute() {
    int index = componentRoutes.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last componentRoutes. The list is empty.");
    return setNewComponentRouteLike(index, buildComponentRoute(index));
  }
  public io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<A> editMatchingComponentRoute(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteStatusBuilder> predicate) {
    int index = -1;
    for (int i=0;i<componentRoutes.size();i++) { 
    if (predicate.test(componentRoutes.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching componentRoutes. No match found.");
    return setNewComponentRouteLike(index, buildComponentRoute(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IngressStatusFluentImpl that = (IngressStatusFluentImpl) o;
    if (componentRoutes != null ? !componentRoutes.equals(that.componentRoutes) :that.componentRoutes != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(componentRoutes,  additionalProperties,  super.hashCode());
  }
  public class ComponentRoutesNestedImpl<N> extends io.fabric8.openshift.api.model.ComponentRouteStatusFluentImpl<io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<N>> implements io.fabric8.openshift.api.model.IngressStatusFluent.ComponentRoutesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ComponentRoutesNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteStatus item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(this, item);
    }
    ComponentRoutesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.ComponentRouteStatusBuilder(this);
    }
    io.fabric8.openshift.api.model.ComponentRouteStatusBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) IngressStatusFluentImpl.this.setToComponentRoutes(index,builder.build());
    }
    public N endComponentRoute() {
      return and();
    }
    
  }
  
}
